@@ -629,12 +629,8 @@ class Update(MethodsInterface):
         if not name.strip():
             name = str(pkg)
 
-        
-        name = str(pkg)
-        name = _u(name)
-
         self.printSUCCESS(
-            _u(_("{part} {package}")).format(part=_u(part), package=name))
+            _u(_("{part} {package}")).format(part=_u(part), package=_u(name)))
         self.startTask(
             _u(_("Emerging {package}")).format(package=_u(_colorprint(str(pkg)))))
 
